Group

Struct Group 

pub struct Group<'f> { /* private fields */ }
A lightweight handle to an HDF5 group.

Implementations

Source

impl<'f> Group<'f>

pub fn datasets(&self) -> Result<Vec<String>, Error>

List the names of datasets in this group.

pub fn groups(&self) -> Result<Vec<String>, Error>

List the names of subgroups in this group.

pub fn attrs(&self) -> Result<HashMap<String, AttrValue>, Error>

Read all attributes of this group.

pub fn dataset(&self, name: &str) -> Result<Dataset<'f>, Error>

Get a dataset within this group by name.

The dataset uses the file-wide chunk-cache default. To override the cache for this one dataset, use dataset_with_options.

pub fn dataset_with_options( &self, name: &str, options: DatasetAccessOptions, ) -> Result<Dataset<'f>, Error>

Get a dataset within this group by name, applying per-dataset DatasetAccessOptions that override file-wide access defaults (HDF5’s DAPL; see H5Pset_chunk_cache).

pub fn group(&self, name: &str) -> Result<Group<'f>, Error>

Get a subgroup within this group by name.