pub struct VlenStringReadOptions { /* private fields */ }Expand description
Allocation limits for reading variable-length strings.
Limits are checked before any string payload is materialized. The payload
byte limit covers the bytes referenced by the VL elements; it excludes the
Vec<String> and String allocation metadata.
Implementations
Sourceimpl VlenStringReadOptions
impl VlenStringReadOptions
Sourcepub const fn with_max_elements(self, max_elements: usize) -> Self
pub const fn with_max_elements(self, max_elements: usize) -> Self
Set the maximum number of VL elements that may be read.
Sourcepub const fn with_max_payload_bytes(self, max_payload_bytes: usize) -> Self
pub const fn with_max_payload_bytes(self, max_payload_bytes: usize) -> Self
Set the maximum total string payload size in bytes.
Sourcepub const fn max_elements(&self) -> Option<usize>
pub const fn max_elements(&self) -> Option<usize>
Return the configured element limit.
Sourcepub const fn max_payload_bytes(&self) -> Option<usize>
pub const fn max_payload_bytes(&self) -> Option<usize>
Return the configured payload-byte limit.